@@ -32,8 +32,8 @@ def prepare_data(root, accelerometer=True, gyroscope=True, orientation=False, st
     file_list = get_file_list(root, ext=".mat")
 
     # for i, fpath in enumerate(file_list):
-    pbar = enumerate(tqdm(file_list, desc="Reading mat files ..."))
-    for i, fpath in pbar:
+    pbar = tqdm(file_list, desc="Reading mat files ...")
+    for i, fpath in enumerate(pbar):
         subject_name = re.search("(S[0-9]+_|[sS]troke[0-9]+)", fpath).group().replace("_", "").lower()
 
         if (stroke and not subject_name.startswith("stroke")) or \
@@ -170,12 +170,12 @@ def make_training_data(data_root, save_root, window_size=300, stride=1, chunk_si
         generate_training_test_data(data, label, subjects, subject_list, training_portion=training_portion,
                                     shuffle=shuffle, verbose=verbose)
 
-    for i, data in enumerate(training_data):
-        if np.sum(np.isnan(data.flatten())) > 0:
+    for i, dd in enumerate(training_data):
+        if np.sum(np.isnan(dd.flatten())) > 0:
             print("NaN Exist after generate training test! (training) on {}".format(i))
 
-    for i, data in enumerate(test_data):
-        if np.sum(np.isnan(data.flatten())) > 0:
+    for i, dd in enumerate(test_data):
+        if np.sum(np.isnan(dd.flatten())) > 0:
             print("NaN Exist after generate training test! (training) on {}".format(i))
 
     save_windowed_dataset_hdf5(training_data, training_label, test_data, test_label,
