@@ -1,4 +1,5 @@
 import h5py
+import numpy as np
 from .preprocess import generate_sliding_window_data
 from .preprocess import reshape_data
 
@@ -28,8 +29,8 @@ def save_windowed_data_hdf5(data, label, s_idx=-1, e_idx=-1, window_size=300, st
     t_label = t_label.astype("int8")
     t_data = t_data.astype('float32')
 
-    for i, d in enumerate(data):
-        if np.sum(np.isnan(d.flatten())) > 0:
+    for i, dd in enumerate(data):
+        if np.sum(np.isnan(dd.flatten())) > 0:
             print("NaN Exist after windowed {} data! on {}".format(prefix, i))
 
     fname_prefix = "{}{}".format(save_root, prefix)
